# 入出力モジュール

`wandas.io` モジュールは、様々なファイル形式の読み書き機能を提供します。

## ファイルリーダー

様々なファイル形式からデータを読み込む機能を提供します。

::: wandas.io.readers

## WAVファイル入出力

WAVファイルの読み書き機能を提供します。

::: wandas.io.wav_io

## WDFファイル入出力

WDF（Wandas Data File）形式の読み書き機能を提供します。このフォーマットはメタデータを含む完全な保存が可能です。

::: wandas.io.wdf_io
